==> kdevelop-3.2.2-i486-1.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libkdevelop.so )
( cd opt/kde/lib ; ln -sf libkdevelop.so.1.0.0 libkdevelop.so )
( cd opt/kde/lib ; rm -rf libkdevpropertyeditor.so.0 )
( cd opt/kde/lib ; ln -sf libkdevpropertyeditor.so.0.0.0 libkdevpropertyeditor.so.0 )
( cd opt/kde/lib ; rm -rf libkdevbuildtoolswidgets.so.0 )
( cd opt/kde/lib ; ln -sf libkdevbuildtoolswidgets.so.0.0.0 libkdevbuildtoolswidgets.so.0 )
( cd opt/kde/lib ; rm -rf libkinterfacedesigner.so )
( cd opt/kde/lib ; ln -sf libkinterfacedesigner.so.0.0.0 libkinterfacedesigner.so )
( cd opt/kde/lib ; rm -rf libkdevextras.so.0 )
( cd opt/kde/lib ; ln -sf libkdevextras.so.0.0.0 libkdevextras.so.0 )
( cd opt/kde/lib ; rm -rf libkdevcatalog.so.0 )
( cd opt/kde/lib ; ln -sf libkdevcatalog.so.0.0.0 libkdevcatalog.so.0 )
( cd opt/kde/lib ; rm -rf libkdevshell.so )
( cd opt/kde/lib ; ln -sf libkdevshell.so.0.0.0 libkdevshell.so )
( cd opt/kde/lib ; rm -rf libprofileengine.so )
( cd opt/kde/lib ; ln -sf libprofileengine.so.0.0.0 libprofileengine.so )
( cd opt/kde/lib ; rm -rf libdocdevhelpplugin.so )
( cd opt/kde/lib ; ln -sf libdocdevhelpplugin.so.0.0.0 libdocdevhelpplugin.so )
( cd opt/kde/lib ; rm -rf libdocdevhelpplugin.so.0 )
( cd opt/kde/lib ; ln -sf libdocdevhelpplugin.so.0.0.0 libdocdevhelpplugin.so.0 )
( cd opt/kde/lib ; rm -rf libdocchmplugin.so.0 )
( cd opt/kde/lib ; ln -sf libdocchmplugin.so.0.0.0 libdocchmplugin.so.0 )
( cd opt/kde/lib ; rm -rf libkdevpropertyeditor.so )
( cd opt/kde/lib ; ln -sf libkdevpropertyeditor.so.0.0.0 libkdevpropertyeditor.so )
( cd opt/kde/lib ; rm -rf liblang_interfaces.so )
( cd opt/kde/lib ; ln -sf liblang_interfaces.so.0.0.0 liblang_interfaces.so )
( cd opt/kde/lib ; rm -rf libdockdevtocplugin.so.0 )
( cd opt/kde/lib ; ln -sf libdockdevtocplugin.so.0.0.0 libdockdevtocplugin.so.0 )
( cd opt/kde/lib ; rm -rf liblang_interfaces.so.0 )
( cd opt/kde/lib ; ln -sf liblang_interfaces.so.0.0.0 liblang_interfaces.so.0 )
( cd opt/kde/lib ; rm -rf libdocchmplugin.so )
( cd opt/kde/lib ; ln -sf libdocchmplugin.so.0.0.0 libdocchmplugin.so )
( cd opt/kde/lib ; rm -rf libkdevshell.so.0 )
( cd opt/kde/lib ; ln -sf libkdevshell.so.0.0.0 libkdevshell.so.0 )
( cd opt/kde/lib ; rm -rf libdockdevtocplugin.so )
( cd opt/kde/lib ; ln -sf libdockdevtocplugin.so.0.0.0 libdockdevtocplugin.so )
( cd opt/kde/lib ; rm -rf libdocdoxygenplugin.so.0 )
( cd opt/kde/lib ; ln -sf libdocdoxygenplugin.so.0.0.0 libdocdoxygenplugin.so.0 )
( cd opt/kde/lib ; rm -rf libkdevbuildbase.so )
( cd opt/kde/lib ; ln -sf libkdevbuildbase.so.0.0.0 libkdevbuildbase.so )
( cd opt/kde/lib ; rm -rf libkinterfacedesigner.so.0 )
( cd opt/kde/lib ; ln -sf libkinterfacedesigner.so.0.0.0 libkinterfacedesigner.so.0 )
( cd opt/kde/lib ; rm -rf libprojectmanager_interfaces.so )
( cd opt/kde/lib ; ln -sf libprojectmanager_interfaces.so.1.0.0 libprojectmanager_interfaces.so )
( cd opt/kde/lib ; rm -rf libdocumentation_interfaces.so.0 )
( cd opt/kde/lib ; ln -sf libdocumentation_interfaces.so.0.0.0 libdocumentation_interfaces.so.0 )
( cd opt/kde/lib ; rm -rf libkdevwidgets.so )
( cd opt/kde/lib ; ln -sf libkdevwidgets.so.0.0.0 libkdevwidgets.so )
( cd opt/kde/lib ; rm -rf libdesignerintegration.so.0 )
( cd opt/kde/lib ; ln -sf libdesignerintegration.so.0.0.0 libdesignerintegration.so.0 )
( cd opt/kde/lib ; rm -rf libprofileengine.so.0 )
( cd opt/kde/lib ; ln -sf libprofileengine.so.0.0.0 libprofileengine.so.0 )
( cd opt/kde/lib ; rm -rf libkdevcppparser.so )
( cd opt/kde/lib ; ln -sf libkdevcppparser.so.0.0.0 libkdevcppparser.so )
( cd opt/kde/lib ; rm -rf libdesignerintegration.so )
( cd opt/kde/lib ; ln -sf libdesignerintegration.so.0.0.0 libdesignerintegration.so )
( cd opt/kde/lib ; rm -rf libkdevbuildtoolswidgets.so )
( cd opt/kde/lib ; ln -sf libkdevbuildtoolswidgets.so.0.0.0 libkdevbuildtoolswidgets.so )
( cd opt/kde/lib ; rm -rf libkdevelop.so.1 )
( cd opt/kde/lib ; ln -sf libkdevelop.so.1.0.0 libkdevelop.so.1 )
( cd opt/kde/lib ; rm -rf libkdevwidgets.so.0 )
( cd opt/kde/lib ; ln -sf libkdevwidgets.so.0.0.0 libkdevwidgets.so.0 )
( cd opt/kde/lib ; rm -rf libprojectmanager_interfaces.so.1 )
( cd opt/kde/lib ; ln -sf libprojectmanager_interfaces.so.1.0.0 libprojectmanager_interfaces.so.1 )
( cd opt/kde/lib ; rm -rf libdocumentation_interfaces.so )
( cd opt/kde/lib ; ln -sf libdocumentation_interfaces.so.0.0.0 libdocumentation_interfaces.so )
( cd opt/kde/lib ; rm -rf libkdevcppparser.so.0 )
( cd opt/kde/lib ; ln -sf libkdevcppparser.so.0.0.0 libkdevcppparser.so.0 )
( cd opt/kde/lib ; rm -rf libkdevcatalog.so )
( cd opt/kde/lib ; ln -sf libkdevcatalog.so.0.0.0 libkdevcatalog.so )
( cd opt/kde/lib ; rm -rf libkdevbuildbase.so.0 )
( cd opt/kde/lib ; ln -sf libkdevbuildbase.so.0.0.0 libkdevbuildbase.so.0 )
( cd opt/kde/lib ; rm -rf liblang_debugger.so.0 )
( cd opt/kde/lib ; ln -sf liblang_debugger.so.0.0.0 liblang_debugger.so.0 )
( cd opt/kde/lib ; rm -rf libkdevextras.so )
( cd opt/kde/lib ; ln -sf libkdevextras.so.0.0.0 libkdevextras.so )
( cd opt/kde/lib ; rm -rf libdocdoxygenplugin.so )
( cd opt/kde/lib ; ln -sf libdocdoxygenplugin.so.0.0.0 libdocdoxygenplugin.so )
( cd opt/kde/lib ; rm -rf liblang_debugger.so )
( cd opt/kde/lib ; ln -sf liblang_debugger.so.0.0.0 liblang_debugger.so )
( cd opt/kde/share/doc/HTML/en/kdevelop-apidocs ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdevelop-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kdevelop ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdevelop ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kde_app_devel ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/en/common common )

==> kdevelop-3.3.4-i486-1.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libkdevelop.so )
( cd opt/kde/lib ; ln -sf libkdevelop.so.1.0.0 libkdevelop.so )
( cd opt/kde/lib ; rm -rf libkdevpropertyeditor.so.0 )
( cd opt/kde/lib ; ln -sf libkdevpropertyeditor.so.0.0.0 libkdevpropertyeditor.so.0 )
( cd opt/kde/lib ; rm -rf libkdevbuildtoolswidgets.so.0 )
( cd opt/kde/lib ; ln -sf libkdevbuildtoolswidgets.so.0.0.0 libkdevbuildtoolswidgets.so.0 )
( cd opt/kde/lib ; rm -rf libkinterfacedesigner.so )
( cd opt/kde/lib ; ln -sf libkinterfacedesigner.so.0.0.0 libkinterfacedesigner.so )
( cd opt/kde/lib ; rm -rf libkdevextras.so.0 )
( cd opt/kde/lib ; ln -sf libkdevextras.so.0.0.0 libkdevextras.so.0 )
( cd opt/kde/lib ; rm -rf libkdevcatalog.so.0 )
( cd opt/kde/lib ; ln -sf libkdevcatalog.so.0.0.0 libkdevcatalog.so.0 )
( cd opt/kde/lib ; rm -rf libd.so )
( cd opt/kde/lib ; ln -sf libd.so.0.0.0 libd.so )
( cd opt/kde/lib ; rm -rf libkdevshell.so )
( cd opt/kde/lib ; ln -sf libkdevshell.so.0.0.0 libkdevshell.so )
( cd opt/kde/lib ; rm -rf libprofileengine.so )
( cd opt/kde/lib ; ln -sf libprofileengine.so.0.0.0 libprofileengine.so )
( cd opt/kde/lib ; rm -rf libdocdevhelpplugin.so )
( cd opt/kde/lib ; ln -sf libdocdevhelpplugin.so.0.0.0 libdocdevhelpplugin.so )
( cd opt/kde/lib ; rm -rf libdocdevhelpplugin.so.0 )
( cd opt/kde/lib ; ln -sf libdocdevhelpplugin.so.0.0.0 libdocdevhelpplugin.so.0 )
( cd opt/kde/lib ; rm -rf libdocchmplugin.so.0 )
( cd opt/kde/lib ; ln -sf libdocchmplugin.so.0.0.0 libdocchmplugin.so.0 )
( cd opt/kde/lib ; rm -rf libkdevpropertyeditor.so )
( cd opt/kde/lib ; ln -sf libkdevpropertyeditor.so.0.0.0 libkdevpropertyeditor.so )
( cd opt/kde/lib ; rm -rf liblang_interfaces.so )
( cd opt/kde/lib ; ln -sf liblang_interfaces.so.0.0.0 liblang_interfaces.so )
( cd opt/kde/lib ; rm -rf libdockdevtocplugin.so.0 )
( cd opt/kde/lib ; ln -sf libdockdevtocplugin.so.0.0.0 libdockdevtocplugin.so.0 )
( cd opt/kde/lib ; rm -rf liblang_interfaces.so.0 )
( cd opt/kde/lib ; ln -sf liblang_interfaces.so.0.0.0 liblang_interfaces.so.0 )
( cd opt/kde/lib ; rm -rf libdocchmplugin.so )
( cd opt/kde/lib ; ln -sf libdocchmplugin.so.0.0.0 libdocchmplugin.so )
( cd opt/kde/lib ; rm -rf libkdevshell.so.0 )
( cd opt/kde/lib ; ln -sf libkdevshell.so.0.0.0 libkdevshell.so.0 )
( cd opt/kde/lib ; rm -rf libdockdevtocplugin.so )
( cd opt/kde/lib ; ln -sf libdockdevtocplugin.so.0.0.0 libdockdevtocplugin.so )
( cd opt/kde/lib ; rm -rf libkdevqmakeparser.so.0 )
( cd opt/kde/lib ; ln -sf libkdevqmakeparser.so.0.0.0 libkdevqmakeparser.so.0 )
( cd opt/kde/lib ; rm -rf libdocdoxygenplugin.so.0 )
( cd opt/kde/lib ; ln -sf libdocdoxygenplugin.so.0.0.0 libdocdoxygenplugin.so.0 )
( cd opt/kde/lib ; rm -rf libkdevbuildbase.so )
( cd opt/kde/lib ; ln -sf libkdevbuildbase.so.0.0.0 libkdevbuildbase.so )
( cd opt/kde/lib ; rm -rf libkinterfacedesigner.so.0 )
( cd opt/kde/lib ; ln -sf libkinterfacedesigner.so.0.0.0 libkinterfacedesigner.so.0 )
( cd opt/kde/lib ; rm -rf libprojectmanager_interfaces.so )
( cd opt/kde/lib ; ln -sf libprojectmanager_interfaces.so.1.0.0 libprojectmanager_interfaces.so )
( cd opt/kde/lib ; rm -rf libdocumentation_interfaces.so.0 )
( cd opt/kde/lib ; ln -sf libdocumentation_interfaces.so.0.0.0 libdocumentation_interfaces.so.0 )
( cd opt/kde/lib ; rm -rf libkdevwidgets.so )
( cd opt/kde/lib ; ln -sf libkdevwidgets.so.0.0.0 libkdevwidgets.so )
( cd opt/kde/lib ; rm -rf libdesignerintegration.so.0 )
( cd opt/kde/lib ; ln -sf libdesignerintegration.so.0.0.0 libdesignerintegration.so.0 )
( cd opt/kde/lib ; rm -rf libkdevqmakeparser.so )
( cd opt/kde/lib ; ln -sf libkdevqmakeparser.so.0.0.0 libkdevqmakeparser.so )
( cd opt/kde/lib ; rm -rf libprofileengine.so.0 )
( cd opt/kde/lib ; ln -sf libprofileengine.so.0.0.0 libprofileengine.so.0 )
( cd opt/kde/lib ; rm -rf libkdevcppparser.so )
( cd opt/kde/lib ; ln -sf libkdevcppparser.so.0.0.0 libkdevcppparser.so )
( cd opt/kde/lib ; rm -rf libdesignerintegration.so )
( cd opt/kde/lib ; ln -sf libdesignerintegration.so.0.0.0 libdesignerintegration.so )
( cd opt/kde/lib ; rm -rf libkdevbuildtoolswidgets.so )
( cd opt/kde/lib ; ln -sf libkdevbuildtoolswidgets.so.0.0.0 libkdevbuildtoolswidgets.so )
( cd opt/kde/lib ; rm -rf libkdevelop.so.1 )
( cd opt/kde/lib ; ln -sf libkdevelop.so.1.0.0 libkdevelop.so.1 )
( cd opt/kde/lib ; rm -rf libkdevwidgets.so.0 )
( cd opt/kde/lib ; ln -sf libkdevwidgets.so.0.0.0 libkdevwidgets.so.0 )
( cd opt/kde/lib ; rm -rf libprojectmanager_interfaces.so.1 )
( cd opt/kde/lib ; ln -sf libprojectmanager_interfaces.so.1.0.0 libprojectmanager_interfaces.so.1 )
( cd opt/kde/lib ; rm -rf libd.so.0 )
( cd opt/kde/lib ; ln -sf libd.so.0.0.0 libd.so.0 )
( cd opt/kde/lib ; rm -rf libdocumentation_interfaces.so )
( cd opt/kde/lib ; ln -sf libdocumentation_interfaces.so.0.0.0 libdocumentation_interfaces.so )
( cd opt/kde/lib ; rm -rf libkdevcppparser.so.0 )
( cd opt/kde/lib ; ln -sf libkdevcppparser.so.0.0.0 libkdevcppparser.so.0 )
( cd opt/kde/lib ; rm -rf libkdevcatalog.so )
( cd opt/kde/lib ; ln -sf libkdevcatalog.so.0.0.0 libkdevcatalog.so )
( cd opt/kde/lib ; rm -rf libkdevbuildbase.so.0 )
( cd opt/kde/lib ; ln -sf libkdevbuildbase.so.0.0.0 libkdevbuildbase.so.0 )
( cd opt/kde/lib ; rm -rf liblang_debugger.so.0 )
( cd opt/kde/lib ; ln -sf liblang_debugger.so.0.0.0 liblang_debugger.so.0 )
( cd opt/kde/lib ; rm -rf libkdevextras.so )
( cd opt/kde/lib ; ln -sf libkdevextras.so.0.0.0 libkdevextras.so )
( cd opt/kde/lib ; rm -rf libdocdoxygenplugin.so )
( cd opt/kde/lib ; ln -sf libdocdoxygenplugin.so.0.0.0 libdocdoxygenplugin.so )
( cd opt/kde/lib ; rm -rf liblang_debugger.so )
( cd opt/kde/lib ; ln -sf liblang_debugger.so.0.0.0 liblang_debugger.so )
( cd opt/kde/share/doc/HTML/en/kdevelop-apidocs ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdevelop-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kdevelop ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdevelop ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kde_app_devel ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/en/common common )
